<!DOCTYPE html><htmllang="en"><head><metacharset="utf-8"><metaname="viewport"content="width=device-width, initial-scale=1.0"><metaname="generator"content="rustdoc"><metaname="description"content="Error returned when a Syn parser cannot parse the input tokens."><title>Error in syn - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../static.files/${f}">`).join(""))</script><linkrel="stylesheet"href="../static.files/normalize-9960930a.css"><linkrel="stylesheet"href="../static.files/rustdoc-84e720fa.css"><metaname="rustdoc-vars"data-root-path="../"data-static-root-path="../static.files/"data-current-crate="syn"data-themes=""data-resource-suffix=""data-rustdoc-version="1.89.0 (29483883e 2025-08-04)"data-channel="1.89.0"data-search-js="search-92309212.js"data-settings-js="settings-5514c975.js"><scriptsrc="../static.files/storage-4e99c027.js"></script><scriptdefersrc="sidebar-items.js"></script><scriptdefersrc="../static.files/main-fd3af306.js"></script><noscript><linkrel="stylesheet"href="../static.files/noscript-32bb7600.css"></noscript><linkrel="alternate icon"type="image/png"href="../static.files/favicon-32x32-6580c154.png"><linkrel="icon"type="image/svg+xml"href="../static.files/favicon-044be391.svg"></head><bodyclass="rustdoc struct"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><navclass="mobile-topbar"><buttonclass="sidebar-menu-toggle"title="show sidebar"></button></nav><navclass="sidebar"><divclass="sidebar-crate"><h2><ahref="../syn/index.html">syn</a><spanclass="version">2.0.106</span></h2></div><divclass="sidebar-elems"><sectionid="rustdoc-toc"><h2class="location"><ahref="#">Error</a></h2><h3><ahref="#">Sections</a></h3><ulclass="block top-toc"><li><ahref="#error-reporting-in-proc-macros"title="Error reporting in proc macros">Error reporting in proc macros</a></li></ul><h3><ahref="#implementations">Methods</a></h3><ulclass="block method"><li><ahref="#method.combine"title="combine">combine</a></li><li><ahref="#method.into_compile_error"title="into_compile_error">into_compile_error</a></li><li><ahref="#method.new"title="new">new</a></li><li><ahref="#method.new_spanned"title="new_spanned">new_spanned</a></li><li><ahref="#method.span"title="span">span</a></li><li><ahref="#method.to_compile_error"title="to_compile_error">to_compile_error</a></li></ul><h3><ahref="#trait-implementations">Trait Implementations</a></h3><ulclass="block trait-implementation"><li><ahref="#impl-Clone-for-Error"title="Clone">Clone</a></li><li><ahref="#impl-Debug-for-Error"title="Debug">Debug</a></li><li><ahref="#impl-Display-for-Error"title="Display">Display</a></li><li><ahref="#impl-Error-for-Error"title="Error">Error</a></li><li><ahref="#impl-Extend%3CError%3E-for-Error"title="Extend<Error>">Extend<Error></a></li><li><ahref="#impl-From%3CLexError%3E-for-Error"title="From<LexError>">From<LexError></a></li><li><ahref="#impl-IntoIterator-for-%26Error"title="IntoIterator">IntoIterator</a></li><li><ahref="#impl-IntoIterator-for-Error"title="IntoIterator">IntoIterator</a></li></ul><h3><ahref="#synthetic-implementations">Auto Trait Implementations</a></h3><ulclass="block synthetic-implementation"><li><ahref="#impl-Freeze-for-Error"title="Freeze">Freeze</a></li><li><ahref="#impl-RefUnwindSafe-for-Error"title="RefUnwindSafe">RefUnwindSafe</a></li><li><ahref="#impl-Send-for-Error"title="Send">Send</a></li><li><ahref="#impl-Sync-for-Error"title="Sync">Sync</a></li><li><ahref="#impl-Unpin-for-Error"title="Unpin">Unpin</a></li><li><ahref="#impl-UnwindSafe-f
<ahref="https://doc.rust-lang.org/1.89.0/core/macro.compile_error.html"title="macro core::compile_error"><code>compile_error!</code></a> in the generated code. This produces a better diagnostic
<p>When parsing macro input, the <ahref="macro.parse_macro_input.html"title="macro syn::parse_macro_input"><code>parse_macro_input!</code></a> macro handles the
<ahref="struct.Error.html#method.to_compile_error"title="method syn::Error::to_compile_error"><code>.to_compile_error()</code></a> or <ahref="struct.Error.html#method.into_compile_error"title="method syn::Error::into_compile_error"><code>.into_compile_error()</code></a> methods can be used to
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.new_spanned"class="method"><aclass="src rightside"href="../src/syn/error.rs.html#189-203">Source</a><h4class="code-header">pub fn <ahref="#method.new_spanned"class="fn">new_spanned</a><T: <aclass="trait"href="../quote/to_tokens/trait.ToTokens.html"title="trait quote::to_tokens::ToTokens">ToTokens</a>, U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a>>(tokens: T, message: U) -> Self</h4></section></summary><divclass="docblock"><p>Creates an error with the specified message spanning the given syntax
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.to_compile_error"class="method"><aclass="src rightside"href="../src/syn/error.rs.html#225-230">Source</a><h4class="code-header">pub fn <ahref="#method.to_compile_error"class="fn">to_compile_error</a>(&self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a></h4></section></summary><divclass="docblock"><p>Render the error as an invocation of <ahref="https://doc.rust-lang.org/1.89.0/core/macro.compile_error.html"title="macro core::compile_error"><code>compile_error!</code></a>.</p>
<p>The <ahref="macro.parse_macro_input.html"title="macro syn::parse_macro_input"><code>parse_macro_input!</code></a> macro provides a convenient way to invoke
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.into_compile_error"class="method"><aclass="src rightside"href="../src/syn/error.rs.html#264-266">Source</a><h4class="code-header">pub fn <ahref="#method.into_compile_error"class="fn">into_compile_error</a>(self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a></h4></section></summary><divclass="docblock"><p>Render the error as an invocation of <ahref="https://doc.rust-lang.org/1.89.0/core/macro.compile_error.html"title="macro core::compile_error"><code>compile_error!</code></a>.</p>
</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.combine"class="method"><aclass="src rightside"href="../src/syn/error.rs.html#270-272">Source</a><h4class="code-header">pub fn <ahref="#method.combine"class="fn">combine</a>(&mut self, another: <aclass="struct"href="struct.Error.html"title="struct syn::Error">Error</a>)</h4></section></summary><divclass="docblock"><p>Add another error message to self such that when <code>to_compile_error()</code> is
<code><ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html"title="trait core::convert::From">From</a><T> for U</code> chooses to do.</p>
</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-ToOwned-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#82-84">Source</a><ahref="#impl-ToOwned-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html"title="trait alloc::borrow::ToOwned">ToOwned</a> for T<divclass="where">where
T: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Owned"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#86">Source</a><ahref="#associatedtype.Owned"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#associatedtype.Owned"class="associatedtype">Owned</a> = T</h4></section></summary><divclass='docblock'>The resulting type after obtaining ownership.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.to_owned"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#87">Source</a><ahref="#method.to_owned"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned"class="fn">to_owned</a>(&self) -> T</h4></section></summary><divclass='docblock'>Creates owned data from borrowed data, usually by cloning. <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned">Read more</a></div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.clone_into"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/borrow.rs.html#91">Source</a><ahref="#method.clone_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#method.clone_into"class="fn">clone_into</a>(&self, target: <aclass="primitive"href="https://doc.rust-lang.org/1.89.0/std/primitive.reference.html">&mut T</a>)</h4></section></summary><divclass='docblock'>Uses borrowed data to replace owned data, usually by cloning. <ahref="https://doc.rust-lang.org/1.89.0/alloc/borrow/trait.ToOwned.html#method.clone_into">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-ToString-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/string.rs.html#2805">Source</a><ahref="#impl-ToString-for-T"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html"title="trait alloc::string::ToString">ToString</a> for T<divclass="where">where
T: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a> + ?<aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle method-toggle"open><summary><sectionid="method.to_string"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/alloc/string.rs.html#2807">Source</a><ahref="#method.to_string"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html#tymethod.to_string"class="fn">to_string</a>(&self) -><aclass="struct"href="https://doc.rust-lang.org/1.89.0/alloc/string/struct.String.html"title="struct alloc::string::String">String</a></h4></section></summary><divclass='docblock'>Converts the given value to a <code>String</code>. <ahref="https://doc.rust-lang.org/1.89.0/alloc/string/trait.ToString.html#tymethod.to_string">Read more</a></div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryFrom%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#813-815">Source</a><ahref="#impl-TryFrom%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html"title="trait core::convert::Into">Into</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error-1"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#817">Source</a><ahref="#associatedtype.Error-1"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"class="associatedtype">Error</a> = <aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/convert/enum.Infallible.html"title="enum core::convert::Infallible">Infallible</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_from"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#820">Source</a><ahref="#method.try_from"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#tymethod.try_from"class="fn">try_from</a>(value: U) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><T, <T as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details><detailsclass="toggle implementors-toggle"><summary><sectionid="impl-TryInto%3CU%3E-for-T"class="impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#798-800">Source</a><ahref="#impl-TryInto%3CU%3E-for-T"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html"title="trait core::convert::TryInto">TryInto</a><U> for T<divclass="where">where
U: <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>,</div></h3></section></summary><divclass="impl-items"><detailsclass="toggle"open><summary><sectionid="associatedtype.Error"class="associatedtype trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#802">Source</a><ahref="#associatedtype.Error"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#associatedtype.Error"class="associatedtype">Error</a> = <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a></h4></section></summary><divclass='docblock'>The type returned in the event of a conversion error.</div></details><detailsclass="toggle method-toggle"open><summary><sectionid="method.try_into"class="method trait-impl"><aclass="src rightside"href="https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#805">Source</a><ahref="#method.try_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#tymethod.try_into"class="fn">try_into</a>(self) -><aclass="enum"href="https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html"title="enum core::result::Result">Result</a><U, <U as <aclass="trait"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><T>>::<aclass="associatedtype"href="https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error"title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><divclass='docblock'>Performs the conversion.</div></details></div></details></div></section></div></main></body></html>