2025-08-20 14:48:48 +00:00
<!DOCTYPE html> < html lang = "en" > < head > < meta charset = "utf-8" > < meta name = "viewport" content = "width=device-width, initial-scale=1.0" > < meta name = "generator" content = "rustdoc" > < meta name = "description" content = "A slice literal expression: `[a, b, c, d]`." > < title > ExprArray in syn - Rust< / title > < script > if ( window . location . protocol !== "file:" ) document . head . insertAdjacentHTML ( "beforeend" , "SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2" . split ( "," ) . map ( f => ` <link rel="preload" as="font" type="font/woff2" crossorigin href="../static.files/ ${ f } "> ` ) . join ( "" ) ) < / script > < link rel = "stylesheet" href = "../static.files/normalize-9960930a.css" > < link rel = "stylesheet" href = "../static.files/rustdoc-84e720fa.css" > < meta name = "rustdoc-vars" data-root-path = "../" data-static-root-path = "../static.files/" data-current-crate = "syn" data-themes = "" data-resource-suffix = "" data-rustdoc-version = "1.89.0 (29483883e 2025-08-04)" data-channel = "1.89.0" data-search-js = "search-92309212.js" data-settings-js = "settings-5514c975.js" > < script src = "../static.files/storage-4e99c027.js" > < / script > < script defer src = "sidebar-items.js" > < / script > < script defer src = "../static.files/main-fd3af306.js" > < / script > < noscript > < link rel = "stylesheet" href = "../static.files/noscript-32bb7600.css" > < / noscript > < link rel = "alternate icon" type = "image/png" href = "../static.files/favicon-32x32-6580c154.png" > < link rel = "icon" type = "image/svg+xml" href = "../static.files/favicon-044be391.svg" > < / head > < body class = "rustdoc struct" > <!-- [if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif] --> < nav class = "mobile-topbar" > < button class = "sidebar-menu-toggle" title = "show sidebar" > < / button > < / nav > < nav class = "sidebar" > < div class = "sidebar-crate" > < h2 > < a href = "../syn/index.html" > syn< / a > < span class = "version" > 2.0.106< / span > < / h2 > < / div > < div class = "sidebar-elems" > < section id = "rustdoc-toc" > < h2 class = "location" > < a href = "#" > Expr< wbr > Array< / a > < / h2 > < h3 > < a href = "#trait-implementations" > Trait Implementations< / a > < / h3 > < ul class = "block trait-implementation" > < li > < a href = "#impl-From%3CExprArray%3E-for-Expr" title = "From<ExprArray>" > From< ExprArray> < / a > < / li > < li > < a href = "#impl-ToTokens-for-ExprArray" title = "ToTokens" > ToTokens< / a > < / li > < / ul > < h3 > < a href = "#synthetic-implementations" > Auto Trait Implementations< / a > < / h3 > < ul class = "block synthetic-implementation" > < li > < a href = "#impl-Send-for-ExprArray" title = "!Send" > !Send< / a > < / li > < li > < a href = "#impl-Sync-for-ExprArray" title = "!Sync" > !Sync< / a > < / li > < li > < a href = "#impl-Freeze-for-ExprArray" title = "Freeze" > Freeze< / a > < / li > < li > < a href = "#impl-RefUnwindSafe-for-ExprArray" title = "RefUnwindSafe" > RefUnwindSafe< / a > < / li > < li > < a href = "#impl-Unpin-for-ExprArray" title = "Unpin" > Unpin< / a > < / li > < li > < a href = "#impl-UnwindSafe-for-ExprArray" title = "UnwindSafe" > UnwindSafe< / a > < / li > < / ul > < h3 > < a href = "#blanket-implementations" > Blanket Implementations< / a > < / h3 > < ul class = "block blanket-implementation" > < li > < a href = "#impl-Any-for-T" title = "Any" > Any< / a > < / li > < li > < a href = "#impl-Borrow%3CT%3E-for-T" title = "Borrow<T>" > Borrow< T> < / a > < / li > < li > < a href = "#impl-BorrowMut%3CT%3E-for-T" title = "BorrowMut<T>" > BorrowMut< T> < / a > < / li > < li > < a href = "#impl-From%3CT%3E-for-T" title = "From<T>" > From< T> < / a > < / li > < li > < a href = "#impl-Into%3CU%3E-for-T" title = "Into<U>" > Into< U> < / a > < / li > < li > < a href = "#impl-Spanned-for-T" title = "Spanned" > Spanned< / a > < / li > < li > < a href = "#impl-TryFrom%3CU%3E-for-T" title = "TryFrom<U>" > TryFrom< U> < / a > < / li > < li > < a href = "#impl-TryInto%3CU%3E-for-T" title = "TryInto<U>" > TryInto< U> < / a > < / li > < / ul > < / section > < div id = "rustdoc-modnav" > < h2 class = "in-crate" > < a href = "index.html" > In crate syn< / a > < / h2 > < / div > < / div > < / nav > < div class = "sidebar-resizer" title = "Drag to resize sidebar" > < / div > < main > < div class = "width-limiter" > < rustdoc-search > < / rustdoc-search > < section id = "main-content" class = "cont
< / div > < / details > < h2 id = "trait-implementations" class = "section-header" > Trait Implementations< a href = "#trait-implementations" class = "anchor" > < / a > < / h2 > < div id = "trait-implementations-list" > < details class = "toggle implementors-toggle" open > < summary > < section id = "impl-From%3CExprArray%3E-for-Expr" class = "impl" > < a class = "src rightside" href = "../src/syn/expr.rs.html#35-267" > Source< / a > < a href = "#impl-From%3CExprArray%3E-for-Expr" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html" title = "trait core::convert::From" > From< / a > < < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > > for < a class = "enum" href = "enum.Expr.html" title = "enum syn::Expr" > Expr< / a > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.from" class = "method trait-impl" > < a class = "src rightside" href = "../src/syn/expr.rs.html#35-267" > Source< / a > < a href = "#method.from" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html#tymethod.from" class = "fn" > from< / a > (e: < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > ) -> < a class = "enum" href = "enum.Expr.html" title = "enum syn::Expr" > Expr< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Converts to this type from the input type.< / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" open > < summary > < section id = "impl-ToTokens-for-ExprArray" class = "impl" > < a class = "src rightside" href = "../src/syn/expr.rs.html#269-277" > Source< / a > < a href = "#impl-ToTokens-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "../quote/to_tokens/trait.ToTokens.html" title = "trait quote::to_tokens::ToTokens" > ToTokens< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.to_tokens" class = "method trait-impl" > < a class = "src rightside" href = "../src/syn/expr.rs.html#269-277" > Source< / a > < a href = "#method.to_tokens" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "../quote/to_tokens/trait.ToTokens.html#tymethod.to_tokens" class = "fn" > to_tokens< / a > (& self, _: & mut < a class = "struct" href = "../proc_macro2/struct.TokenStream.html" title = "struct proc_macro2::TokenStream" > TokenStream< / a > )< / h4 > < / section > < / summary > < div class = 'docblock' > Write < code > self< / code > to the given < code > TokenStream< / code > . < a href = "../quote/to_tokens/trait.ToTokens.html#tymethod.to_tokens" > Read more< / a > < / div > < / details > < details class = "toggle method-toggle" open > < summary > < section id = "method.to_token_stream" class = "method trait-impl" > < a class = "src rightside" href = "../src/quote/to_tokens.rs.html#56" > Source< / a > < a href = "#method.to_token_stream" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "../quote/to_tokens/trait.ToTokens.html#method.to_token_stream" class = "fn" > to_token_stream< / a > (& self) -> < a class = "struct" href = "../proc_macro2/struct.TokenStream.html" title = "struct proc_macro2::TokenStream" > TokenStream< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Convert < code > self< / code > directly into a < code > TokenStream< / code > object. < a href = "../quote/to_tokens/trait.ToTokens.html#method.to_token_stream" > Read more< / a > < / div > < / details > < details class = "toggle method-toggle" open > < summary > < section id = "method.into_token_stream" class = "method trait-impl" > < a class = "src rightside" href = "../src/quote/to_tokens.rs.html#66-68" > Source< / a > < a href = "#method.into_token_stream" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "../quote/to_tokens/trait.ToTokens.html#method.into_token_stream" class = "fn" > into_token_stream< / a > (self) -> < a class = "struct" href = "../proc_macro2/struct.TokenStream.html" title = "struct proc_macro2::TokenStream" > TokenStream< / a > < div class = "where" > where
Self: < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html" title = "trait core::marker::Sized" > Sized< / a > ,< / div > < / h4 > < / section > < / summary > < div class = 'docblock' > Convert < code > self< / code > directly into a < code > TokenStream< / code > object. < a href = "../quote/to_tokens/trait.ToTokens.html#method.into_token_stream" > Read more< / a > < / div > < / details > < / div > < / details > < / div > < h2 id = "synthetic-implementations" class = "section-header" > Auto Trait Implementations< a href = "#synthetic-implementations" class = "anchor" > < / a > < / h2 > < div id = "synthetic-implementations-list" > < section id = "impl-Freeze-for-ExprArray" class = "impl" > < a href = "#impl-Freeze-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Freeze.html" title = "trait core::marker::Freeze" > Freeze< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < section id = "impl-RefUnwindSafe-for-ExprArray" class = "impl" > < a href = "#impl-RefUnwindSafe-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/panic/unwind_safe/trait.RefUnwindSafe.html" title = "trait core::panic::unwind_safe::RefUnwindSafe" > RefUnwindSafe< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < section id = "impl-Send-for-ExprArray" class = "impl" > < a href = "#impl-Send-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl !< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Send.html" title = "trait core::marker::Send" > Send< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < section id = "impl-Sync-for-ExprArray" class = "impl" > < a href = "#impl-Sync-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl !< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sync.html" title = "trait core::marker::Sync" > Sync< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < section id = "impl-Unpin-for-ExprArray" class = "impl" > < a href = "#impl-Unpin-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Unpin.html" title = "trait core::marker::Unpin" > Unpin< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < section id = "impl-UnwindSafe-for-ExprArray" class = "impl" > < a href = "#impl-UnwindSafe-for-ExprArray" class = "anchor" > < / a > < h3 class = "code-header" > impl < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/panic/unwind_safe/trait.UnwindSafe.html" title = "trait core::panic::unwind_safe::UnwindSafe" > UnwindSafe< / a > for < a class = "struct" href = "struct.ExprArray.html" title = "struct syn::ExprArray" > ExprArray< / a > < / h3 > < / section > < / div > < h2 id = "blanket-implementations" class = "section-header" > Blanket Implementations< a href = "#blanket-implementations" class = "anchor" > < / a > < / h2 > < div id = "blanket-implementations-list" > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-Any-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/any.rs.html#138" > Source< / a > < a href = "#impl-Any-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html" title = "trait core::any::Any" > Any< / a > for T< div class = "where" > where
T: 'static + ?< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html" title = "trait core::marker::Sized" > Sized< / a > ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.type_id" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/any.rs.html#139" > Source< / a > < a href = "#method.type_id" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html#tymethod.type_id" class = "fn" > type_id< / a > (& self) -> < a class = "struct" href = "https://doc.rust-lang.org/1.89.0/core/any/struct.TypeId.html" title = "struct core::any::TypeId" > TypeId< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Gets the < code > TypeId< / code > of < code > self< / code > . < a href = "https://doc.rust-lang.org/1.89.0/core/any/trait.Any.html#tymethod.type_id" > Read more< / a > < / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-Borrow%3CT%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#209" > Source< / a > < a href = "#impl-Borrow%3CT%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html" title = "trait core::borrow::Borrow" > Borrow< / a > < T> for T< div class = "where" > where
T: ?< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html" title = "trait core::marker::Sized" > Sized< / a > ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.borrow" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#211" > Source< / a > < a href = "#method.borrow" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html#tymethod.borrow" class = "fn" > borrow< / a > (& self) -> < a class = "primitive" href = "https://doc.rust-lang.org/1.89.0/std/primitive.reference.html" > & T< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Immutably borrows from an owned value. < a href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.Borrow.html#tymethod.borrow" > Read more< / a > < / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-BorrowMut%3CT%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#217" > Source< / a > < a href = "#impl-BorrowMut%3CT%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html" title = "trait core::borrow::BorrowMut" > BorrowMut< / a > < T> for T< div class = "where" > where
T: ?< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html" title = "trait core::marker::Sized" > Sized< / a > ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.borrow_mut" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/borrow.rs.html#218" > Source< / a > < a href = "#method.borrow_mut" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut" class = "fn" > borrow_mut< / a > (& mut self) -> < a class = "primitive" href = "https://doc.rust-lang.org/1.89.0/std/primitive.reference.html" > & mut T< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Mutably borrows from an owned value. < a href = "https://doc.rust-lang.org/1.89.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut" > Read more< / a > < / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-From%3CT%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#774" > Source< / a > < a href = "#impl-From%3CT%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html" title = "trait core::convert::From" > From< / a > < T> for T< / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.from-1" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#777" > Source< / a > < a href = "#method.from-1" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html#tymethod.from" class = "fn" > from< / a > (t: T) -> T< / h4 > < / section > < / summary > < div class = "docblock" > < p > Returns the argument unchanged.< / p >
< / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-Into%3CU%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#757-759" > Source< / a > < a href = "#impl-Into%3CU%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T, U> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html" title = "trait core::convert::Into" > Into< / a > < U> for T< div class = "where" > where
U: < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html" title = "trait core::convert::From" > From< / a > < T> ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.into" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#767" > Source< / a > < a href = "#method.into" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html#tymethod.into" class = "fn" > into< / a > (self) -> U< / h4 > < / section > < / summary > < div class = "docblock" > < p > Calls < code > U::from(self)< / code > .< / p >
2023-02-07 01:24:14 +00:00
< p > That is, this conversion is whatever the implementation of
2025-08-20 14:48:48 +00:00
< code > < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.From.html" title = "trait core::convert::From" > From< / a > < T> for U< / code > chooses to do.< / p >
2025-01-24 08:59:28 +00:00
< / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-Spanned-for-T" class = "impl" > < a class = "src rightside" href = "../src/syn/spanned.rs.html#104-108" > Source< / a > < a href = "#impl-Spanned-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T> < a class = "trait" href = "spanned/trait.Spanned.html" title = "trait syn::spanned::Spanned" > Spanned< / a > for T< div class = "where" > where
2025-08-20 14:48:48 +00:00
T: Spanned + ?< a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/marker/trait.Sized.html" title = "trait core::marker::Sized" > Sized< / a > ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle method-toggle" open > < summary > < section id = "method.span" class = "method trait-impl" > < a class = "src rightside" href = "../src/syn/spanned.rs.html#105-107" > Source< / a > < a href = "#method.span" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "spanned/trait.Spanned.html#tymethod.span" class = "fn" > span< / a > (& self) -> < a class = "struct" href = "../proc_macro2/struct.Span.html" title = "struct proc_macro2::Span" > Span< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > Returns a < code > Span< / code > covering the complete contents of this syntax tree
node, or < a href = "../proc_macro2/struct.Span.html#method.call_site" title = "associated function proc_macro2::Span::call_site" > < code > Span::call_site()< / code > < / a > if this node is empty.< / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-TryFrom%3CU%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#813-815" > Source< / a > < a href = "#impl-TryFrom%3CU%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T, U> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html" title = "trait core::convert::TryFrom" > TryFrom< / a > < U> for T< div class = "where" > where
U: < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.Into.html" title = "trait core::convert::Into" > Into< / a > < T> ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle" open > < summary > < section id = "associatedtype.Error-1" class = "associatedtype trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#817" > Source< / a > < a href = "#associatedtype.Error-1" class = "anchor" > < / a > < h4 class = "code-header" > type < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error" class = "associatedtype" > Error< / a > = < a class = "enum" href = "https://doc.rust-lang.org/1.89.0/core/convert/enum.Infallible.html" title = "enum core::convert::Infallible" > Infallible< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > The type returned in the event of a conversion error.< / div > < / details > < details class = "toggle method-toggle" open > < summary > < section id = "method.try_from" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#820" > Source< / a > < a href = "#method.try_from" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#tymethod.try_from" class = "fn" > try_from< / a > (value: U) -> < a class = "enum" href = "https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html" title = "enum core::result::Result" > Result< / a > < T, < T as < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html" title = "trait core::convert::TryFrom" > TryFrom< / a > < U> > ::< a class = "associatedtype" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error" title = "type core::convert::TryFrom::Error" > Error< / a > > < / h4 > < / section > < / summary > < div class = 'docblock' > Performs the conversion.< / div > < / details > < / div > < / details > < details class = "toggle implementors-toggle" > < summary > < section id = "impl-TryInto%3CU%3E-for-T" class = "impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#798-800" > Source< / a > < a href = "#impl-TryInto%3CU%3E-for-T" class = "anchor" > < / a > < h3 class = "code-header" > impl< T, U> < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html" title = "trait core::convert::TryInto" > TryInto< / a > < U> for T< div class = "where" > where
U: < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html" title = "trait core::convert::TryFrom" > TryFrom< / a > < T> ,< / div > < / h3 > < / section > < / summary > < div class = "impl-items" > < details class = "toggle" open > < summary > < section id = "associatedtype.Error" class = "associatedtype trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#802" > Source< / a > < a href = "#associatedtype.Error" class = "anchor" > < / a > < h4 class = "code-header" > type < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#associatedtype.Error" class = "associatedtype" > Error< / a > = < U as < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html" title = "trait core::convert::TryFrom" > TryFrom< / a > < T> > ::< a class = "associatedtype" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error" title = "type core::convert::TryFrom::Error" > Error< / a > < / h4 > < / section > < / summary > < div class = 'docblock' > The type returned in the event of a conversion error.< / div > < / details > < details class = "toggle method-toggle" open > < summary > < section id = "method.try_into" class = "method trait-impl" > < a class = "src rightside" href = "https://doc.rust-lang.org/1.89.0/src/core/convert/mod.rs.html#805" > Source< / a > < a href = "#method.try_into" class = "anchor" > < / a > < h4 class = "code-header" > fn < a href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryInto.html#tymethod.try_into" class = "fn" > try_into< / a > (self) -> < a class = "enum" href = "https://doc.rust-lang.org/1.89.0/core/result/enum.Result.html" title = "enum core::result::Result" > Result< / a > < U, < U as < a class = "trait" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html" title = "trait core::convert::TryFrom" > TryFrom< / a > < T> > ::< a class = "associatedtype" href = "https://doc.rust-lang.org/1.89.0/core/convert/trait.TryFrom.html#associatedtype.Error" title = "type core::convert::TryFrom::Error" > Error< / a > > < / h4 > < / section > < / summary > < div class = 'docblock' > Performs the conversion.< / div > < / details > < / div > < / details > < / div > < / section > < / div > < / main > < / body > < / html >